@@ -434,8 +434,9 @@ class Ui_MainWindow(object):
         self.datafolder_button.setText(_translate("MainWindow", "Data folder"))
         self.workingVar_label.setText(_translate("MainWindow", "WorkingVar Label (e.g, A)"))
         self.medpctoexcel_button.setText(_translate("MainWindow", "MED-PC to Excel"))
-        self.override.setItemText(0, _translate("MainWindow", "Override existing data"))
-        self.override.setItemText(1, _translate("MainWindow", "Skip existing data"))
+        self.override.setItemText(0, _translate("MainWindow", "Append"))        
+        self.override.setItemText(1, _translate("MainWindow", "Replace"))
+        self.override.setItemText(2, _translate("MainWindow", "Override"))
         self.medpctoexcel_progressbar.setFormat(_translate("MainWindow", "%p%"))
         self.tabs.setTabText(self.tabs.indexOf(self.genExcel), _translate("MainWindow", "Generate Excel"))
         self.load_datafile.setText(_translate("MainWindow", "Load file"))
@@ -446,7 +447,7 @@ class Ui_MainWindow(object):
         self.label_sessiondur.setText(_translate("MainWindow", "Session duration (mins)"))
         self.plot.setText(_translate("MainWindow", "Plot"))
         self.tabs.setTabText(self.tabs.indexOf(self.dataexplorer), _translate("MainWindow", "Data Explorer"))
-        self.info_label.setText(_translate("MainWindow", "Current version v3.0 \n"
+        self.info_label.setText(_translate("MainWindow", "Current version v3.0.2 \n"
 "Created by Yifeng Cheng, Ph.D. \n"
 "Contact:\n"
 "(979)571-8531\n"
@@ -462,10 +463,7 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
         Ui_MainWindow.__init__(self)
         self.setupUi(self)
         self.datafolder_button.clicked.connect (self.__set_data_folder_frombutton)
-        self.load_configfile_button.clicked.connect (self.__load_configfile_frombutton)
         self.medpctoexcel_button.clicked.connect(self.__run_medpc2excel)
-        self.genTSfile_button.clicked.connect (self.__genTSfile)
-        self.genVar_button.clicked.connect(self.__genvars)
         self.load_datafile.clicked.connect(self.__load_exceldata_file_frombutton)
         self.update_events_list_Button.clicked.connect(self.__update_events_list_frombutton)
         self.add_events_Button.clicked.connect(self.__add_select_events_frombutton)
